import os

BASE_DIR = os.path.dirname(__file__)
HEADERS = {
    'Content-Type': 'application/json',
    'User-Agent': 'transdryad/PaperMC-Updater/1.0 (viswanath.hazel@gmail.com)',
    'accept': 'application/json',
}
CURRENT_DIR = os.getcwd()
